searchData={"items":[{"type":"module","title":"Jmap","doc":"Basic JMAP client for Elixir.\n\nThis module provides a high-level interface for interacting with JMAP email servers.\nIt handles all the complexity of fetching emails, downloading blobs, and sanitizing content.\n\nIt was purpose built for fetching a single email at a time from FastMail. However, it may\nserve for others as a useful starting point for building a more feature rich client.","ref":"Jmap.html"},{"type":"module","title":"Configuration - Jmap","doc":"In order to use JMAP, you'll need to configure a JMAP provider, token, and options.\n\n```elixir\nconfig :jmap,\n  provider: \"fastmail\",\n  api_token: \"your_api_token\",\n  opts: [inline_images: true]\n```","ref":"Jmap.html#module-configuration"},{"type":"module","title":"Options - Jmap","doc":"- `inline_images`: Whether the inline images in the email body are converted to base64 and embedded in the email body. Defaults to `true`.","ref":"Jmap.html#module-options"},{"type":"module","title":"HTTP Client - Jmap","doc":"The library uses Erlang's built-in `:httpc` module by default. If you want to use the more feature-rich `req` package instead, simply add it as a dependency:\n\n```elixir\ndefp deps do\n  [\n    {:req, \"~> 0.5.10 or ~> 0.6 or ~> 1.0\"}\n  ]\nend\n```\n\nThe library will automatically use `req` if it's available, falling back to `:httpc` if it's not.","ref":"Jmap.html#module-http-client"},{"type":"module","title":"Creating a client - Jmap","doc":"Once you have a provider and token, you can create a client.\n\n```elixir\n{:ok, client} = Jmap.new()\n```\n\nThis returns an authenticated client struct or fails if the provider or token are invalid.","ref":"Jmap.html#module-creating-a-client"},{"type":"module","title":"Getting email - Jmap","doc":"```elixir\n{:ok, email} = Jmap.get_next_mail(client)\n#=> %Jmap.Email{\n  id: \"Md45jz\",\n  subject: \"Meeting Tomorrow\",\n  from: [\n    %Jmap.Email.EmailAddress{\n      name: \"John Smith\",\n      email: \"john.smith@example.com\"\n    }\n  ],\n  to: [\n    %Jmap.Email.EmailAddress{\n      name: \"Jane Doe\",\n      email: \"jane.doe@example.com\"\n    }\n  ],\n  received_at: \"2024-03-20T15:30:00Z\",\n  text_body: [\n    %Jmap.Email.EmailBody{\n      blob_id: \"blob_123\",\n      type: \"text/plain\",\n      charset: \"utf-8\",\n      part_id: \"part1\",\n      size: 423,\n      contents: \"Hi Jane,\\n\\nJust confirming our meeting tomorrow at 2pm.\\n\\nBest regards,\\nJohn\"\n    },\n    %Jmap.Email.EmailBody{\n      blob_id: \"blob_124\",\n      type: \"text/plain\",\n      charset: \"utf-8\",\n      part_id: \"part2\",\n      size: 256,\n      contents: \"> On Thu, Mar 21, 2024 at 10:00 AM Jane Doe   wrote:\\n> > Hi John,\\n> > \\n> > Let's meet tomorrow at 2pm.\"\n    }\n  ],\n  html_body: [\n    %Jmap.Email.EmailBody{\n      blob_id: \"blob_125\",\n      type: \"text/html\",\n      charset: \"utf-8\",\n      part_id: \"part3\",\n      size: 628,\n      contents: \"  Hi Jane,  Just confirming our meeting tomorrow at 2pm.  Best regards, John  \"\n    }\n  ],\n  attachments: [\n    %Jmap.Email.Attachment{\n      blob_id: \"blob_126\",\n      type: \"application/pdf\",\n      name: \"agenda.pdf\",\n      size: 125_840,\n      disposition: \"attachment\",\n      contents: <<...>>  # Binary content\n    }\n  ],\n  thread_id: \"thread_789\",\n  original_quote: %Jmap.Email.EmailBody{\n    blob_id: \"blob_124\",\n    type: \"text/plain\",\n    charset: \"utf-8\",\n    part_id: \"part2\",\n    size: 256,\n    contents: \"> On Thu, Mar 21, 2024 at 10:00 AM Jane Doe   wrote:\\n> > Hi John,\\n> > \\n> > Let's meet tomorrow at 2pm.\"\n  }\n}\n```\n\nThis returns the next email from the inbox. By default, it will return the oldest email first.\nYou can pass a `limit` and `offset` to paginate through the emails.\n\n```elixir\n{:ok, email} = Jmap.get_next_mail(client, limit: 10, offset: 0)\n```\n\nYou can also change the default sort order by passing a `sort` option.\n\n```elixir\n{:ok, email} = Jmap.get_next_mail(client,\n  sort: [%{\"isAscending\" => false, \"property\" => \"receivedAt\"}])\n```","ref":"Jmap.html#module-getting-email"},{"type":"module","title":"Get an email by ID. - Jmap","doc":"This works exactly like `Jmap.get_next_mail/1` but it will return an email by ID.\n\n```elixir\n{:ok, email} = Jmap.get_email(client, \"email_id\")\n```\n\nThis returns an email by ID.","ref":"Jmap.html#module-get-an-email-by-id"},{"type":"function","title":"Jmap.archive_email/2","doc":"","ref":"Jmap.html#archive_email/2"},{"type":"function","title":"Jmap.fetch_blob/2","doc":"","ref":"Jmap.html#fetch_blob/2"},{"type":"function","title":"Jmap.fetch_email/2","doc":"","ref":"Jmap.html#fetch_email/2"},{"type":"function","title":"Jmap.fetch_emails/2","doc":"","ref":"Jmap.html#fetch_emails/2"},{"type":"function","title":"Jmap.get_email/2","doc":"Fetches an email by its ID, including its full contents.\n\nThis function handles all the complexity of:\n- Fetching the email metadata\n- Downloading the email body contents\n- Downloading attachment contents\n- Sanitizing HTML content\n- Inlining embedded images\n- Converting the data into a structured format","ref":"Jmap.html#get_email/2"},{"type":"function","title":"Parameters - Jmap.get_email/2","doc":"- client: The JMAP client struct\n  - email_id: The ID of the email to fetch","ref":"Jmap.html#get_email/2-parameters"},{"type":"function","title":"Examples - Jmap.get_email/2","doc":"iex> Jmap.get_email(client, \"email123\")\n    {:ok, %Jmap.Email{\n      subject: \"Hello\",\n      text_body: [\n        %{contents: \"Hello world\", type: \"text/plain\"},\n        %{contents: \"> Previous message\", type: \"text/plain\"}\n      ],\n      html_body: [\n        %{contents: \" Hello world \", type: \"text/html\"}\n      ],\n      original_quote: %{\n        contents: \"> On Thu, Mar 21, 2024 at 10:00 AM John Doe   wrote:\n> > Hi there,\n> > \n> > This is the original message.\",\n        type: \"text/plain\"\n      }\n    }}\n    iex> Jmap.get_email(client, \"email123\")\n    {:error, \"Email not found\"}","ref":"Jmap.html#get_email/2-examples"},{"type":"function","title":"Jmap.get_next_mail/1","doc":"Fetches the oldest email from the inbox, including its full contents.\n\nThis function handles all the complexity of:\n- Fetching the email metadata\n- Downloading the email body contents\n- Downloading attachment contents\n- Sanitizing HTML content\n- Inlining embedded images\n- Converting the data into a structured format","ref":"Jmap.html#get_next_mail/1"},{"type":"function","title":"Parameters - Jmap.get_next_mail/1","doc":"- client: The JMAP client struct","ref":"Jmap.html#get_next_mail/1-parameters"},{"type":"function","title":"Examples - Jmap.get_next_mail/1","doc":"iex> Jmap.get_next_mail(client)\n    {:ok, %Jmap.Email{\n      subject: \"Hello\",\n      text_body: [\n        %{contents: \"Hello world\", type: \"text/plain\"},\n        %{contents: \"> Previous message\", type: \"text/plain\"}\n      ],\n      html_body: [\n        %{contents: \" Hello world \", type: \"text/html\"}\n      ],\n      original_quote: %{\n        contents: \"> On Thu, Mar 21, 2024 at 10:00 AM John Doe   wrote:\n> > Hi there,\n> > \n> > This is the original message.\",\n        type: \"text/plain\"\n      }\n    }}\n    iex> Jmap.get_next_mail(client)\n    {:error, \"Inbox empty\"}","ref":"Jmap.html#get_next_mail/1-examples"},{"type":"function","title":"Jmap.new/0","doc":"","ref":"Jmap.html#new/0"},{"type":"function","title":"Jmap.new/3","doc":"","ref":"Jmap.html#new/3"},{"type":"module","title":"Jmap.Client","doc":"JMAP client implementation that handles the core protocol communication.","ref":"Jmap.Client.html"},{"type":"function","title":"Jmap.Client.archive_email/2","doc":"Archives the specified email by moving it to the Archive folder.","ref":"Jmap.Client.html#archive_email/2"},{"type":"function","title":"Jmap.Client.fetch_blob/3","doc":"Fetches the content of a blob by its ID.","ref":"Jmap.Client.html#fetch_blob/3"},{"type":"function","title":"Parameters - Jmap.Client.fetch_blob/3","doc":"- client: The JMAP client struct\n  - blob_id: The ID of the blob to fetch\n  - type: The expected content type (optional)\n    - \"text/html\" or \"text/plain\" will return a string\n    - \"application/octet-stream\" or other types will return binary","ref":"Jmap.Client.html#fetch_blob/3-parameters"},{"type":"function","title":"Returns - Jmap.Client.fetch_blob/3","doc":"* `{:ok, content}` - on success\n    - For text types: {:ok, string}\n    - For binary types: {:ok, binary}\n  * `{:error, reason}` - on failure","ref":"Jmap.Client.html#fetch_blob/3-returns"},{"type":"function","title":"Examples - Jmap.Client.fetch_blob/3","doc":"iex> Jmap.Client.fetch_blob(client, \"blob123\", \"text/html\")\n    {:ok, \" ... \"}\n    iex> Jmap.Client.fetch_blob(client, \"blob123\", \"application/octet-stream\")\n    {:ok, <<...>>}","ref":"Jmap.Client.html#fetch_blob/3-examples"},{"type":"function","title":"Jmap.Client.fetch_email/2","doc":"Fetches the full content of a specific email.","ref":"Jmap.Client.html#fetch_email/2"},{"type":"function","title":"Parameters - Jmap.Client.fetch_email/2","doc":"- client: The JMAP client struct\n  - email_id: The ID of the email to fetch","ref":"Jmap.Client.html#fetch_email/2-parameters"},{"type":"function","title":"Returns - Jmap.Client.fetch_email/2","doc":"* `{:ok, email}` - on success, where email contains:\n    - id: The email ID\n    - subject: The email subject\n    - from: List of sender email addresses\n    - to: List of recipient email addresses\n    - receivedAt: Timestamp when the email was received\n    - textBody: List of text/plain body parts\n    - htmlBody: List of text/html body parts\n    - attachments: List of attachments\n    - threadId: The thread ID this email belongs to\n  * `{:error, reason}` - on failure","ref":"Jmap.Client.html#fetch_email/2-returns"},{"type":"function","title":"Examples - Jmap.Client.fetch_email/2","doc":"iex> Jmap.Client.fetch_email(client, \"email123\")\n    {:ok, %{\n      \"id\" => \"email123\",\n      \"subject\" => \"Hello\",\n      \"from\" => [%{\"email\" => \"sender@example.com\", \"name\" => \"Sender\"}],\n      \"to\" => [%{\"email\" => \"recipient@example.com\", \"name\" => \"Recipient\"}],\n      \"receivedAt\" => \"2024-01-01T00:00:00Z\",\n      \"textBody\" => [\n        %{\"blobId\" => \"blob123\", \"type\" => \"text/plain\"},\n        %{\"blobId\" => \"blob124\", \"type\" => \"text/plain\"}\n      ],\n      \"htmlBody\" => [\n        %{\"blobId\" => \"blob125\", \"type\" => \"text/html\"}\n      ],\n      \"attachments\" => [],\n      \"threadId\" => \"thread123\"\n    }}","ref":"Jmap.Client.html#fetch_email/2-examples"},{"type":"function","title":"Jmap.Client.fetch_emails/2","doc":"Fetches emails from the Inbox.","ref":"Jmap.Client.html#fetch_emails/2"},{"type":"function","title":"Options - Jmap.Client.fetch_emails/2","doc":"- limit: Maximum number of emails to fetch (default: 50)\n  - offset: Number of emails to skip (default: 0)\n  - sort: Custom sort order (default: [%{\"isAscending\" => true, \"property\" => \"receivedAt\"}])","ref":"Jmap.Client.html#fetch_emails/2-options"},{"type":"function","title":"Returns - Jmap.Client.fetch_emails/2","doc":"* `{:ok, result}` - on success, where result contains:\n    - \"ids\": List of email IDs\n    - \"total\": Total number of emails\n    - \"position\": Current position in the result set\n  * `{:error, reason}` - on failure","ref":"Jmap.Client.html#fetch_emails/2-returns"},{"type":"function","title":"Jmap.Client.fetch_thread/2","doc":"Fetches a thread by its ID.","ref":"Jmap.Client.html#fetch_thread/2"},{"type":"function","title":"Parameters - Jmap.Client.fetch_thread/2","doc":"- client: The JMAP client struct\n  - thread_id: The ID of the thread to fetch","ref":"Jmap.Client.html#fetch_thread/2-parameters"},{"type":"function","title":"Returns - Jmap.Client.fetch_thread/2","doc":"* `{:ok, thread}` - on success, containing thread ID and associated email IDs\n  * `{:error, reason}` - on failure","ref":"Jmap.Client.html#fetch_thread/2-returns"},{"type":"function","title":"Examples - Jmap.Client.fetch_thread/2","doc":"iex> Jmap.Client.fetch_thread(client, \"thread123\")\n    {:ok, %Jmap.Thread{id: \"thread123\", emailIds: [\"email1\", \"email2\"]}}","ref":"Jmap.Client.html#fetch_thread/2-examples"},{"type":"function","title":"Jmap.Client.new/0","doc":"Creates a new JMAP client using configuration values.","ref":"Jmap.Client.html#new/0"},{"type":"function","title":"Returns - Jmap.Client.new/0","doc":"* `{:ok, client}` - on success\n  * `{:error, reason}` - on failure","ref":"Jmap.Client.html#new/0-returns"},{"type":"function","title":"Examples - Jmap.Client.new/0","doc":"iex> Jmap.new()\n    {:ok, %Jmap.Client{}}","ref":"Jmap.Client.html#new/0-examples"},{"type":"function","title":"Jmap.Client.new/3","doc":"Creates a new JMAP client with the given configuration.","ref":"Jmap.Client.html#new/3"},{"type":"function","title":"Parameters - Jmap.Client.new/3","doc":"- api_token: The JMAP API token (for Fastmail, generate this in Settings -> Password & Security -> App Passwords)\n  - provider: The JMAP provider (e.g., :fastmail)\n  - options: Additional options (optional)\n    - api_url: Custom API URL (defaults to provider's default)\n    - timeout: Request timeout in milliseconds (default: 30_000)","ref":"Jmap.Client.html#new/3-parameters"},{"type":"function","title":"Returns - Jmap.Client.new/3","doc":"* `{:ok, client}` - on success\n  * `{:error, reason}` - on failure","ref":"Jmap.Client.html#new/3-returns"},{"type":"function","title":"Examples - Jmap.Client.new/3","doc":"iex> Jmap.new(\"your-api-token\", :fastmail)\n    {:ok, %Jmap.Client{}}","ref":"Jmap.Client.html#new/3-examples"},{"type":"module","title":"Jmap.Email","doc":"Represents an email message from the JMAP API.","ref":"Jmap.Email.html"},{"type":"type","title":"Jmap.Email.attachment/0","doc":"Represents an email attachment.\n\nFields:\n- blob_id: Unique identifier for the attachment blob\n- charset: Character encoding if applicable\n- cid: Content-ID for inline attachments\n- disposition: How the attachment should be handled\n- language: Content language code\n- location: URI indicating where the attachment can be found\n- name: Filename of the attachment\n- part_id: Identifier for this specific email part\n- size: Size of the attachment in bytes\n- type: MIME type of the attachment\n- contents: The binary content of the attachment","ref":"Jmap.Email.html#t:attachment/0"},{"type":"type","title":"Jmap.Email.email_address/0","doc":"Represents an email address with an optional display name.\n\nFields:\n- name: Optional display name (e.g., \"John Doe\")\n- email: The actual email address (e.g., \"john@example.com\")","ref":"Jmap.Email.html#t:email_address/0"},{"type":"type","title":"Jmap.Email.email_body/0","doc":"Represents the body content of an email, either in text or HTML format.\n\nFields:\n- blob_id: Unique identifier for the content blob\n- charset: Character encoding of the content\n- cid: Content-ID for inline attachments\n- disposition: How the content should be displayed\n- language: The list of language tags\n- location: URI indicating where the content can be found\n- name: Optional name for the content part\n- part_id: Identifier for this specific email part\n- size: Size of the content in bytes\n- type: MIME type of the content\n- contents: The actual content string","ref":"Jmap.Email.html#t:email_body/0"},{"type":"function","title":"Jmap.Email.new/1","doc":"Creates a new Email struct from raw JMAP data.","ref":"Jmap.Email.html#new/1"},{"type":"function","title":"Parameters - Jmap.Email.new/1","doc":"- `data`: Map containing the raw email data from JMAP","ref":"Jmap.Email.html#new/1-parameters"},{"type":"function","title":"Examples - Jmap.Email.new/1","doc":"iex> data = %{\n    ...>   \"id\" => \"email123\",\n    ...>   \"subject\" => \"Hello\",\n    ...>   \"from\" => [%{\"email\" => \"sender@example.com\", \"name\" => \"Sender\"}],\n    ...>   \"to\" => [%{\"email\" => \"recipient@example.com\", \"name\" => \"Recipient\"}],\n    ...>   \"receivedAt\" => \"2024-01-01T00:00:00Z\",\n    ...>   \"textBody\" => [\n    ...>     %{\"blobId\" => \"blob123\", \"type\" => \"text/plain\"},\n    ...>     %{\"blobId\" => \"blob124\", \"type\" => \"text/plain\"}\n    ...>   ],\n    ...>   \"threadId\" => \"thread123\"\n    ...> }\n    iex> Email.new(data)\n    %Email{\n      id: \"email123\",\n      subject: \"Hello\",\n      from: [%EmailAddress{email: \"sender@example.com\", name: \"Sender\"}],\n      to: [%EmailAddress{email: \"recipient@example.com\", name: \"Recipient\"}],\n      received_at: \"2024-01-01T00:00:00Z\",\n      text_body: [\n        %EmailBody{blob_id: \"blob123\", type: \"text/plain\"},\n        %EmailBody{blob_id: \"blob124\", type: \"text/plain\"}\n      ],\n      html_body: [],\n      attachments: [],\n      thread_id: \"thread123\",\n      original_quote: nil\n    }","ref":"Jmap.Email.html#new/1-examples"},{"type":"function","title":"Jmap.Email.same_thread?/2","doc":"Checks if two emails are part of the same thread.","ref":"Jmap.Email.html#same_thread?/2"},{"type":"function","title":"Parameters - Jmap.Email.same_thread?/2","doc":"- `email1`: First Email struct\n  - `email2`: Second Email struct","ref":"Jmap.Email.html#same_thread?/2-parameters"},{"type":"function","title":"Examples - Jmap.Email.same_thread?/2","doc":"iex> email1 = %Email{thread_id: \"thread123\"}\n    iex> email2 = %Email{thread_id: \"thread123\"}\n    iex> Email.same_thread?(email1, email2)\n    true\n\n    iex> email1 = %Email{thread_id: \"thread123\"}\n    iex> email2 = %Email{thread_id: \"thread456\"}\n    iex> Email.same_thread?(email1, email2)\n    false","ref":"Jmap.Email.html#same_thread?/2-examples"},{"type":"type","title":"Jmap.Email.t/0","doc":"Represents a complete email message with all its components.\n\nFields:\n- id: Unique identifier for the email\n- subject: Email subject line\n- from: List of sender email addresses\n- to: List of recipient email addresses\n- received_at: Timestamp when the email was received\n- text_body: List of plain text versions of the email body\n- html_body: List of HTML versions of the email body\n- attachments: List of files attached to the email\n- thread_id: Identifier for the conversation thread this email belongs to\n- original_quote: The quoted text from previous emails in the thread","ref":"Jmap.Email.html#t:t/0"},{"type":"module","title":"Jmap.Email.Attachment","doc":"Represents an email attachment from the JMAP API.","ref":"Jmap.Email.Attachment.html"},{"type":"type","title":"Jmap.Email.Attachment.t/0","doc":"","ref":"Jmap.Email.Attachment.html#t:t/0"},{"type":"module","title":"Jmap.Email.EmailAddress","doc":"Represents an email address with an optional display name.","ref":"Jmap.Email.EmailAddress.html"},{"type":"type","title":"Jmap.Email.EmailAddress.t/0","doc":"","ref":"Jmap.Email.EmailAddress.html#t:t/0"},{"type":"module","title":"Jmap.Email.EmailBody","doc":"Represents a part of the email body (text or HTML).","ref":"Jmap.Email.EmailBody.html"},{"type":"type","title":"Jmap.Email.EmailBody.t/0","doc":"","ref":"Jmap.Email.EmailBody.html#t:t/0"},{"type":"module","title":"Jmap.Helpers.String","doc":"Helper functions for working with strings safely and cleanly,\nespecially for sanitizing HTML blobs from JMAP or email sources.","ref":"Jmap.Helpers.String.html"},{"type":"function","title":"Jmap.Helpers.String.sanitize_printable/1","doc":"Sanitizes a binary by removing invalid UTF-8 sequences and non-printable characters.\n\nThis version walks the entire string, skipping any invalid bytes instead of stopping early.","ref":"Jmap.Helpers.String.html#sanitize_printable/1"},{"type":"function","title":"Examples - Jmap.Helpers.String.sanitize_printable/1","doc":"iex> Jmap.Helpers.String.sanitize_printable(\"abc\\x01\\x02😀\")\n    \"abc😀\"","ref":"Jmap.Helpers.String.html#sanitize_printable/1-examples"},{"type":"module","title":"Jmap.Thread","doc":"Represents an thread from the JMAP API.","ref":"Jmap.Thread.html"},{"type":"type","title":"Jmap.Thread.t/0","doc":"","ref":"Jmap.Thread.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}